@@ -28,16 +28,16 @@ DEFAULT_BASE_TAGS = {
     'centos': {'name': 'quay.io/centos/centos', 'tag': 'stream9'},
     'debian': {'name': 'debian', 'tag': 'bookworm'},
     'rocky': {'name': 'quay.io/rockylinux/rockylinux', 'tag': '9'},
-    'ubuntu': {'name': 'ubuntu', 'tag': '22.04'},
+    'ubuntu': {'name': 'ubuntu', 'tag': '24.04'},
 }
 # NOTE(hrw): has to match PRETTY_NAME in /etc/os-release
 DISTRO_PRETTY_NAME = {
     'centos': 'CentOS Stream 9',
     'debian': 'Debian GNU/Linux 12 (bookworm)',
     'rocky': 'Rocky Linux 9.* (Blue Onyx)',
-    'ubuntu': 'Ubuntu 2{2,4}.04',
+    'ubuntu': 'Ubuntu 24.04.* LTS',
 }
-OPENSTACK_RELEASE = '2024.1'
+OPENSTACK_RELEASE = '2024.2'
 
 # TODO(mandre) check for file integrity instead of downloading from an HTTPS
 # source
@@ -296,29 +296,20 @@ _BASE_OPTS = [
 
 def get_source_opts(type_=None, location=None, reference=None, enabled=True,
                     version=None, sha256=None):
-    return [cfg.StrOpt('type',
-                       choices=['local', 'git', 'url'],
+    return [cfg.StrOpt('type', choices=['local', 'git', 'url'],
                        default=type_,
                        help='Source location type'),
-            cfg.StrOpt('location',
-                       default=location,
+            cfg.StrOpt('location', default=location,
                        help='The location for source install'),
-            cfg.StrOpt('reference',
-                       default=reference,
+            cfg.StrOpt('reference', default=reference,
                        help=('Git reference to pull, commit sha, tag '
                              'or branch name')),
-            cfg.BoolOpt('enabled',
-                        default=enabled,
+            cfg.BoolOpt('enabled', default=enabled,
                         help=('Whether the source is enabled')),
-            cfg.StrOpt('version',
-                       default=version,
+            cfg.StrOpt('version', default=version,
                        help=('Package version to download for GitHub '
                              'sources')),
-            cfg.DictOpt('sha256',
-                        default=sha256,
-                        help=('Dictionary of sha256 sums for GitHub '
-                              'sources')),
-            ]
+            cfg.DictOpt('sha256', default=sha256)]
 
 
 def get_user_opts(uid, gid, group):
@@ -386,9 +377,6 @@ def parse(conf, args, usage=None, prog=None,
     openstack_branch_slashed = openstack_branch.replace('-', '/')
     conf.set_default('openstack_branch', openstack_branch)
     conf.set_default('openstack_branch_slashed', openstack_branch_slashed)
-    # NOTE(bbezak) Derive debian_arch from base_arch if not set explicitly
-    derived_arch = 'arm64' if conf.base_arch == 'aarch64' else 'amd64'
-    conf.set_default('debian_arch', derived_arch)
 
     if not conf.base_image:
         conf.base_image = DEFAULT_BASE_TAGS[conf.base]['name']
